POP-tools: Tools to support analysis of POP2-CESM model solutions with xarray
=============================================================================


.. image:: https://img.shields.io/github/workflow/status/NCAR/pop-tools/CI?label=CI&logo=github&style=for-the-badge
    :target: https://github.com/NCAR/pop-tools/actions?query=workflow%3ACI
    :alt: GitHub Workflow CI Status

.. image:: https://img.shields.io/github/workflow/status/NCAR/pop-tools/linting?label=linting&logo=github&style=for-the-badge
    :target: https://github.com/NCAR/pop-tools/actions?query=workflow%3Alinting
    :alt: GitHub Workflow Linting Status

.. image:: https://img.shields.io/codecov/c/github/NCAR/pop-tools.svg?style=for-the-badge
    :target: https://codecov.io/gh/NCAR/pop-tools

.. image:: https://img.shields.io/readthedocs/pop-tools/latest.svg?style=for-the-badge
    :target: https://pop-tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/pop-tools.svg?style=for-the-badge
    :target: https://pypi.org/project/pop-tools
    :alt: Python Package Index

.. image:: https://img.shields.io/conda/vn/conda-forge/pop-tools.svg?style=for-the-badge
    :target: https://anaconda.org/conda-forge/pop-tools
    :alt: Conda Version



See full documentation_ for more information.

.. _documentation: https://pop-tools.readthedocs.io/en/latest/


Installation
------------

POP-tools can be installed from PyPI with pip:

.. code-block:: bash

    pip install pop-tools


It is also available from `conda-forge` for conda installations:

.. code-block:: bash

    conda install -c conda-forge pop-tools
